@@ -767,6 +767,9 @@ class HDF5Reader:
         event_id = {mk: self.classes_indexes[mk] for mk in markers}
         events = [[i, 1, event_id[cls]] for i, cls in enumerate(classes)]
 
+        length = (tmax * sampling_rate) - (tmin * sampling_rate)
+        data = list(filter(lambda d: d.shape[-1] == int(length), data))
+
         if preprocess:
             data = preprocess(np.array(data))
         else:
@@ -899,7 +902,7 @@ class HDF5Reader:
         """
 
         epochs = self.get_epochs(
-            eeg, tmax, tmin, markers, preprocess=preprocess)
+            tmax, tmin, markers, eeg=eeg, preprocess=preprocess)
         return epochs._data, epochs.events[:, 2]
 
     # # ----------------------------------------------------------------------
